Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitaly.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Okstad <pokstad@gitlab.com>2019-06-03 23:56:02 +0300
committerPaul Okstad <pokstad@gitlab.com>2019-06-03 23:56:02 +0300
commit5c1584a79ccf71c725aa6f23622c03b6ddc03bc7 (patch)
tree7c709e2ba58084d3130db6da1ad237ebe9bbdcb9
parentcf9f718ba73015d8bdef7c536dd73594a2dc7a3e (diff)
parentada80ec49481a938b81fae1e64b454a454f92c58 (diff)
Merge branch 'typo-fixes' into 'master'
Typo Fixes See merge request gitlab-org/gitaly!1278
-rw-r--r--_support/makegen.go2
-rw-r--r--client/dial.go2
-rw-r--r--internal/diff/diff_test.go2
-rw-r--r--internal/middleware/limithandler/concurrency_limiter_test.go2
-rw-r--r--internal/service/commit/count_diverging_commits.go2
-rw-r--r--internal/service/commit/filter_shas_with_signatures_test.go2
-rw-r--r--internal/service/repository/create_from_snapshot.go2
-rw-r--r--internal/service/repository/fsck_test.go6
-rw-r--r--internal/supervisor/supervisor.go2
-rw-r--r--ruby/lib/gitlab/git/operation_service.rb2
-rw-r--r--ruby/lib/gitlab/git/repository.rb2
-rw-r--r--ruby/spec/lib/gitlab/git/remote_repository_client_spec.rb2
12 files changed, 14 insertions, 14 deletions
diff --git a/_support/makegen.go b/_support/makegen.go
index 70578f533..dddba1096 100644
--- a/_support/makegen.go
+++ b/_support/makegen.go
@@ -274,7 +274,7 @@ var templateText = `
# makegen.go.
#
-# These variables may be overriden at runtime by top-level make
+# These variables may be overridden at runtime by top-level make
PREFIX ?= /usr/local
INSTALL_DEST_DIR := $(DESTDIR)$(PREFIX)/bin/
BUNDLE_FLAGS ?= --deployment
diff --git a/client/dial.go b/client/dial.go
index 1874cc6e1..190cb7ca9 100644
--- a/client/dial.go
+++ b/client/dial.go
@@ -55,7 +55,7 @@ func Dial(rawAddress string, connOpts []grpc.DialOption) (*grpc.ClientConn, erro
connOpts = append(connOpts, grpc.WithInsecure())
case unixConnection:
- canonicalAddress = rawAddress // This will be overriden by the custom dialer...
+ canonicalAddress = rawAddress // This will be overridden by the custom dialer...
connOpts = append(
connOpts,
grpc.WithInsecure(),
diff --git a/internal/diff/diff_test.go b/internal/diff/diff_test.go
index 9684642f5..d0a1837e4 100644
--- a/internal/diff/diff_test.go
+++ b/internal/diff/diff_test.go
@@ -215,7 +215,7 @@ func TestDiffParserWithLargeDiffOfSmallPatches(t *testing.T) {
`
// Create 3 files of 5 lines. The first two files added together surpass
- // the limits, which should cause the last one to be collpased.
+ // the limits, which should cause the last one to be collapsed.
for i := 0; i < 3; i++ {
rawDiff += fmt.Sprintf(`diff --git a/expand-collapse/file-%d.txt b/expand-collapse/file-%d.txt
new file mode 100644
diff --git a/internal/middleware/limithandler/concurrency_limiter_test.go b/internal/middleware/limithandler/concurrency_limiter_test.go
index 8fe1c829e..76797da2a 100644
--- a/internal/middleware/limithandler/concurrency_limiter_test.go
+++ b/internal/middleware/limithandler/concurrency_limiter_test.go
@@ -142,7 +142,7 @@ func TestLimiter(t *testing.T) {
wg.Add(tt.concurrency)
// We know of an edge case that can lead to the rate limiter
- // occassionally letting one or two extra goroutines run
+ // occasionally letting one or two extra goroutines run
// concurrently.
for c := 0; c < tt.concurrency; c++ {
go func(counter int) {
diff --git a/internal/service/commit/count_diverging_commits.go b/internal/service/commit/count_diverging_commits.go
index 4e7df0a42..729f9561d 100644
--- a/internal/service/commit/count_diverging_commits.go
+++ b/internal/service/commit/count_diverging_commits.go
@@ -14,7 +14,7 @@ import (
"gitlab.com/gitlab-org/gitaly/internal/git"
)
-// CountDivergingCommits counts the diverging commits between from and to. Important to note that when --max-count is applied, the counts are not gauranteed to be
+// CountDivergingCommits counts the diverging commits between from and to. Important to note that when --max-count is applied, the counts are not guaranteed to be
// accurate because --max-count is applied before it does the rev walk.
func (s *server) CountDivergingCommits(ctx context.Context, req *gitalypb.CountDivergingCommitsRequest) (*gitalypb.CountDivergingCommitsResponse, error) {
if err := validateCountDivergingCommitsRequest(req); err != nil {
diff --git a/internal/service/commit/filter_shas_with_signatures_test.go b/internal/service/commit/filter_shas_with_signatures_test.go
index dbda54e65..3a4b6cc16 100644
--- a/internal/service/commit/filter_shas_with_signatures_test.go
+++ b/internal/service/commit/filter_shas_with_signatures_test.go
@@ -44,7 +44,7 @@ func TestFilterShasWithSignaturesSuccessful(t *testing.T) {
out: [][]byte{[]byte("5937ac0a7beb003549fc5fd26fc247adbce4a52e"), []byte("6f6d7e7ed97bb5f0054f2b1df789b39ca89b6ff9")},
},
{
- desc: "3 shas, middle non-existant",
+ desc: "3 shas, middle non-existent",
in: [][]byte{[]byte("5937ac0a7beb003549fc5fd26fc247adbce4a52e"), []byte("deadf00d00000000000000000000000000000000"), []byte("6f6d7e7ed97bb5f0054f2b1df789b39ca89b6ff9")},
out: [][]byte{[]byte("5937ac0a7beb003549fc5fd26fc247adbce4a52e"), []byte("6f6d7e7ed97bb5f0054f2b1df789b39ca89b6ff9")},
},
diff --git a/internal/service/repository/create_from_snapshot.go b/internal/service/repository/create_from_snapshot.go
index f307a8d3f..6084f060b 100644
--- a/internal/service/repository/create_from_snapshot.go
+++ b/internal/service/repository/create_from_snapshot.go
@@ -21,7 +21,7 @@ import (
// httpTransport defines a http.Transport with values that are more restrictive
// than for http.DefaultTransport.
//
-// They define shorter TLS Handshake, and more agressive connection closing
+// They define shorter TLS Handshake, and more aggressive connection closing
// to prevent the connection hanging and reduce FD usage.
var httpTransport = &http.Transport{
Proxy: http.ProxyFromEnvironment,
diff --git a/internal/supervisor/supervisor.go b/internal/supervisor/supervisor.go
index e93838256..c6c9a7e22 100644
--- a/internal/supervisor/supervisor.go
+++ b/internal/supervisor/supervisor.go
@@ -61,7 +61,7 @@ type Process struct {
stopOnce sync.Once
}
-// New creates a new proces instance.
+// New creates a new process instance.
func New(name string, env []string, args []string, dir string, memoryThreshold int, events chan<- Event, healthCheck func() error) (*Process, error) {
if len(args) < 1 {
return nil, fmt.Errorf("need at least one argument")
diff --git a/ruby/lib/gitlab/git/operation_service.rb b/ruby/lib/gitlab/git/operation_service.rb
index 2b3355c0d..48559d4e7 100644
--- a/ruby/lib/gitlab/git/operation_service.rb
+++ b/ruby/lib/gitlab/git/operation_service.rb
@@ -106,7 +106,7 @@ module Gitlab
#
# Returns the generated commit.
#
- # ref - The target ref path we're commiting to.
+ # ref - The target ref path we're committing to.
# from_branch - The branch we're taking the HEAD commit from.
def commit_ref(ref, from_branch:)
update_autocrlf_option
diff --git a/ruby/lib/gitlab/git/repository.rb b/ruby/lib/gitlab/git/repository.rb
index b6203094e..49a400347 100644
--- a/ruby/lib/gitlab/git/repository.rb
+++ b/ruby/lib/gitlab/git/repository.rb
@@ -660,7 +660,7 @@ module Gitlab
def remove_remote(remote_name)
# When a remote is deleted all its remote refs are deleted too, but in
- # the case of mirrors we map its refs (that would usualy go under
+ # the case of mirrors we map its refs (that would usually go under
# [remote_name]/) to the top level namespace. We clean the mapping so
# those don't get deleted.
rugged.config.delete("remote.#{remote_name}.fetch") if rugged.config["remote.#{remote_name}.mirror"]
diff --git a/ruby/spec/lib/gitlab/git/remote_repository_client_spec.rb b/ruby/spec/lib/gitlab/git/remote_repository_client_spec.rb
index 500c33953..8375a0187 100644
--- a/ruby/spec/lib/gitlab/git/remote_repository_client_spec.rb
+++ b/ruby/spec/lib/gitlab/git/remote_repository_client_spec.rb
@@ -62,7 +62,7 @@ describe Gitlab::Git::GitalyRemoteRepository do
end
context 'when SSL_CERT_DIR is set' do
- it 'Should return concatenation of gitalycert and gitalycert2 and gitalycert3 ommiting gitalycertdup.pem' do
+ it 'Should return concatenation of gitalycert and gitalycert2 and gitalycert3 omitting gitalycertdup.pem' do
cert_pool_dir = File.join(File.dirname(__FILE__), "testdata/certs")
allow(ENV).to receive(:[]).with('GITLAB_TRACING').and_call_original
allow(ENV).to receive(:[]).with('SSL_CERT_DIR').and_return(cert_pool_dir)
diff --git a/internal/service/repository/fsck_test.go b/internal/service/repository/fsck_test.go
index a1c6ca850..dce33887e 100644
--- a/internal/service/repository/fsck_test.go
+++ b/internal/service/repository/fsck_test.go
@@ -31,7 +31,7 @@ func TestFsckSuccess(t *testing.T) {
assert.Empty(t, c.GetError())
}
-func TestFsckFailureSeverlyBrokenRepo(t *testing.T) {
+func TestFsckFailureSeverelyBrokenRepo(t *testing.T) {
ctx, cancel := testhelper.Context()
defer cancel()
@@ -44,7 +44,7 @@ func TestFsckFailureSeverlyBrokenRepo(t *testing.T) {
testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
defer cleanupFn()
// This makes the repo severly broken so that `git` does not identify it as a
// proper repo.
require.NoError(t, os.RemoveAll(path.Join(testRepoPath, "objects")))
fd, err := os.Create(path.Join(testRepoPath, "objects"))
@@ -70,7 +70,7 @@ func TestFsckFailureSlightlyBrokenRepo(t *testing.T) {
testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
defer cleanupFn()
- // This makes the repo slighly broken so that `git` still identify it as a
+ // This makes the repo slightly broken so that `git` still identify it as a
// proper repo, but `fsck` complains about broken refs...
require.NoError(t, os.RemoveAll(path.Join(testRepoPath, "objects", "pack")))
@@ -44,7 +44,7 @@ func TestFsckFailureSeverlyBrokenRepo(t *testing.T) {
testRepo, testRepoPath, cleanupFn := testhelper.NewTestRepo(t)
defer cleanupFn()
- // This makes the repo severly broken so that `git` does not identify it as a
+ // This makes the repo severely broken so that `git` does not identify it as a
// proper repo.
require.NoError(t, os.RemoveAll(path.Join(testRepoPath, "objects")))